Contributors
============

The following users and developers have contributed to Isomer:

- Heiko 'riot' Weinen (Primary maintainer)
- Johannes 'ijon' Rundfeldt
- Martin Ling

Isomer proudly uses the circuits framework. circuits was originally designed,
written and primarily maintained by James Mills (http://prologic.shortcircuit.net.au/).

Anyone not listed here, ping us. We appreciate any and all
contributions to Isomer and other Hackerfleet components.

Supporters
==========

- **Repository and issue tracker hosting:**
  `Github <https://github.com">`_
- **Free OSS license of IntelliJ IDEA Ultimate:**
  `Jetbrains <https://jetbrains.com">`_
- **Free OSS cross platform/browser user interface testing:**
  `Browserstack <https://browserstack.com>`_
- **Initial project conception phase funding:**
  Kenny Bentley
- **Hosting and nix expertise:**
  Lassulus



.. todo:: Remove/Merge original list and asset docs to this document
